@@ -561,8 +561,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "slug": slug
         }
 
-        logging.info("Channel id {}".format(channel_id))
-
         if self._env == 'dev':
             smart_insight_url = url_list['BASE_URL_INSIGHT_DEV']
         if self._env == 'qa':
@@ -577,8 +575,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        logging.info("AUTH URL {}".format(url))
-
         headers = {
             "Content-Type": "application/json",
             "Authorization": "Bearer" + " " + self._token
@@ -604,6 +600,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
             logging.info("QUERY URL {}".format(query_url))
             r = s.put(url=query_url, json=body_query, headers=headers)
 
+        logging.info("DATACARD {} CREATED".format(slug))
+
         return Insight_Definition(self._env, self._token, definition)
 
     def get_datacard(self, slug):
