@@ -609,6 +609,41 @@ class Insight_Definition:
         map_id = self.add_component("map", position)
         return map_id
 
+    def add_image(self, image_url):
+        position = (len(self.components))
+        image_id = self.add_component("image", position)
+        self.edit_image(image_id, image_url)
+        return image_id
+
+    def edit_image(self, image_id,image_url, image_name="Image 1"):
+
+        body = {
+            "id":image_id,
+            "type":"image",
+            "name":image_name,
+            "customName":False,
+            "dependsOn":[],
+            "valid":True,
+            "queryComponent":False,
+            "link": image_url
+        }
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/images/"+image_id
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
     def add_sql_query(self, query_sql, dataset_slug, is_native = False):
 
         position = (len(self.components))
